#include <stdio.h>
#include "iriver.h"

#define FNC_NUM 15
void progress_func(const char *foo)
{
	printf("badaboom %s\n", foo);
}

void help(char *prog) 
{
	printf("usage: %s command params\n",prog);
	printf("commands:\n");
	printf("\tls directory\n");
	printf("\tdf\n");
	printf("\tupload ifpfile localfile\n");
	printf("\tdownload ifpfile local_target\n");
	printf("\trm file\n");
	printf("\trmdir dir\n");
	printf("\tmkdir dir\n");
	printf("\tbattery\n");
	printf("\ttypestring\n");
	printf("\tfirmversion\n");
	printf("\tformat\n");
	printf("\tfirmupdate /path/to/IFP-1XXTC.HEX or IFP-1XXT.HEX\n");
	printf("\tfileinfo /path/to/iriver/file\n");
	printf("\tdld /path/to/iriver_dir /path/to/local_dir\n");
	printf("\tupd /path/to/iriver_dir /path/to/local_dir\n");
	printf("\n");
	exit(0);
}

int check_for_error(int i)
{
	if (i == IRIVER_OK) return IRIVER_OK;
	  else 
	if (i < 0)
		{
			printf("%s\n", ifp_error_to_string(i));
			exit(i);
		}
	return i;
}

int function_num(const char * str)
{
	int i;
	char *fnc[FNC_NUM]=
		{
			"ls",
			"df",
			"upload",
			"download",
			"rm",
			"rmdir",
			"mkdir",
			"battery",
			"typestring",
			"firmversion",
			"format",
			"firmupdate",
			"fileinfo",
			"dld",
			"upd"
		};

	for (i=0; i<FNC_NUM; i++) if (strcmp(str,fnc[i])==0) return i;
	return FNC_NUM;
}

int main(int argc, char **argv)
{
	usb_dev_handle *dh = NULL;
	static ifp_file_info *list=NULL, *f=NULL;
	char type_str[200];

	if (argc==1) help(argv[0]);
	check_for_error(ifp_init(&dh, IRIVER_INIT));
	switch (function_num(argv[1]))
		{
			case	0: 
				if (argc!=3) help(argv[0]);
				check_for_error(ifp_ls(dh, argv[2], &list));
				f=list;
				while (list!=NULL) { printf("%s\t%d\t%s\n",list->name, list->size,list->mimetype); list=list->next;}
				ifp_free_file_list(&f);
				break;
			case 1:
				printf("Capacity: %d\n", check_for_error(ifp_get_capacity(dh)));
				printf("Free space: %d\n", check_for_error(ifp_get_free(dh)));
				break;
			case 2:
				if (argc!=4) help(argv[0]);
				check_for_error(ifp_upload_file(dh, argv[2], argv[3], progress_func));
				break;
			case 3:
				if (argc!=4) help(argv[0]);
				check_for_error(ifp_download_file(dh, argv[2], argv[3], progress_func));
				break;
			case 4:
				if (argc!=3) help(argv[0]);
				check_for_error(ifp_delete_file(dh, argv[2], progress_func));
				break;
			case 5:
				if (argc!=3) help(argv[0]);
				check_for_error(ifp_delete_dir(dh, argv[2], progress_func));
				break;
			case 6:
				if (argc!=3) help(argv[0]);
				check_for_error(ifp_make_dir(dh, argv[2]));
				break;
			case 7:
				printf("Battery condition: %d\n", check_for_error(ifp_battery_condition(dh)));
				break;
			case 8:
				check_for_error(ifp_model_name(dh, type_str));
				printf("Type string: %s\n",type_str);
				break;
			case 9:
				printf("Firmware version: %0.2f\n", ifp_firmware_version(dh));
				break;
			case 10:
				check_for_error(ifp_format(dh));
				break;
			case 11:
				if (argc!=3) help(argv[0]);
				check_for_error(ifp_firmware_update(&dh, argv[2]));
				break;
			case 12:
				if (argc!=3) help(argv[0]);
				check_for_error(ifp_get_info(dh, argv[2], &list));
				f=list;
				printf("%s\t%d\t%s\n",list->name, list->size,list->mimetype);
				ifp_free_file_list(&f);
				break;
			case 13:
				check_for_error(ifp_download_dir(dh, argv[2], argv[3], progress_func));
				break;
			case 14:
//	check_for_error(ifp_upload_dir(dh, argv[2], argv[3]));
				break;
			case FNC_NUM:
				help(argv[0]);
		}
		ifp_release(dh);	
	return 0;
}


